; ra.iss: install ra using inno installer
; RA_TODO: add user internet setting to the Rgui command line
; RA_TODO: allow user to install not at the default place
; RA_TODO: only install quick start icon if there is already an R quick start icon

[Setup]
AppName=Ra
AppVerName=Ra 1.0.6
DefaultDirName={code:UserPF}\R\{code:RVersion}
DefaultGroupName=R
Compression=lzma/ultra
SolidCompression=yes
DisableStartupPrompt=yes
PrivilegesRequired=none
; don't ask "R-DIR already exists, install to that folder anyway?"
DirExistsWarning=no
UninstallDisplayIcon={app}\bin-ra\Rgui.exe
SetupIconFile=\a\r\ra\src\gnuwin32\front-ends\R.ico
; following displayed in Add/Remove Programs for Ra
AppPublisherURL=http://www.milbo.users.sonic.net
; don't show "Select Destination Location" window
; because if user changes it then our copy from bin to bin-ra will fail
DisableDirPage=yes
; don't show "Select Start Menu Folder" window
DisableProgramGroupPage=yes
; don't show "Ready To Install", it suprises the the user if the above two windows aren't shown
DisableReadyPage=yes

[Icons]
Name: "{group}\Ra\Ra"; Filename: "{app}\bin-ra\Rgui.exe"; WorkingDir: "{app}\bin"; Parameters: {code:CmdParms}
Name: "{group}\Ra\Uninstall Ra"; Filename: "{uninstallexe}"
Name: "{group}\Ra\Ra README"; Filename: "{app}\bin-ra\README-RaWin32.html"; IconFilename: "{app}\bin-ra\Rgui.exe"
Name: "{commondesktop}\Ra"; Filename: "{app}\bin-ra\Rgui.exe"; WorkingDir: "{app}\bin"; MinVersion: 4,4; Parameters: {code:CmdParms}
Name: "{userappdata}\Microsoft\Internet Explorer\Quick Launch\Ra"; Filename: "{app}\bin-ra\Rgui.exe"; WorkingDir: "{app}\bin"; Check: RQuickStart; Parameters: {code:CmdParms}

[Code]

var
  Internet2: Integer;

function RVersion(Param:String): String;
begin
  Result := 'R-2.6.2';
end;

function RQuickStart: boolean;
begin
  Result := TRUE;
end;

function IsAdmin: boolean;
begin
  Result := IsAdminLoggedOn or IsPowerUserLoggedOn;
end;

function UserPF(Param:String): String;
begin
  Result := ExpandConstant('{pf}');
  if (not IsAdmin) then 
  begin
    try
      Result := ExpandConstant('{userdocs}');
    except
    // Do nothing, user doesn't have a My Documents folder
    end;
  end;
end;

procedure InitializeWizard;
begin
  Internet2 := 0;
  // RA_TODO: this doesn't work, it gets the previous data for Ra, we want R
  // case GetPreviousData('Internet', '') of
  //  'Standard':  Internet2 := 0;
  //  'Internet2': Internet2 := 1;
  //else
  //  Internet2 := 0;
  //end;  
end;

function CmdParms(Param:String): String;
begin
  Result := '';
  if Internet2 = 1 then
    Result := '--internet2';
end;

procedure CurStepChanged(CurStep: TSetupStep);
var 
  RDir: String;
  RGui: String;
begin
  if (CurStep = ssInstall) then // actual installation is about to start?
  begin
    RDir := UserPf('') + '\R\' + RVersion('');
    if (not DirExists(RDir)) then
    begin
      MsgBox(RDir + ' does not exist' #13
             '(possibly because ' + RVersion('') + ' is not installed).' #13 #13
             'Ra installation cannot continue.', mbError, MB_OK);
      Abort;
    end;
    RGui := UserPf('') + + '\R\' + RVersion('') + '\bin\Rgui.exe';
    if (not FileExists(RGui)) then
    begin
      MsgBox(RGui + ' does not exist' #13
             '(possibly because ' + RVersion('') + ' is not installed).' #13 #13
             'Ra installation cannot continue.', mbError, MB_OK);
      Abort;
    end;
  end;
end;

[Files]

; Copy bin to bin-ra
Source: "{app}\bin\*"; DestDir: "{app}\bin-ra"; Flags: external ignoreversion

; Replace selected files in bin-ra with the Ra versions
Source: "\a\r\ra\bin\Rgui.exe";  DestDir: "{app}\bin-ra"; Flags: ignoreversion
Source: "\a\r\ra\bin\R.exe";     DestDir: "{app}\bin-ra"; Flags: ignoreversion
Source: "\a\r\ra\bin\R.dll";     DestDir: "{app}\bin-ra"; Flags: ignoreversion

Source: "\a\homepage\ra\ra.png"; DestDir: "{app}\bin-ra"; Flags: ignoreversion
Source: "README-RaWin32.html";   DestDir: "{app}\bin-ra"; Flags: ignoreversion isreadme

; Create jit library
Source: "\a\r\ra\library\jit\*";  DestDir: "{app}\library\jit"; Flags: ignoreversion recursesubdirs uninsneveruninstall
